#!/usr/bin/env python
# -*- coding:utf-8 -*-
# Author: wxnacy(wxnacy@gmail.com)
# Description:

from requests.auth import HTTPBasicAuth
import json
import requests
import base64
import time
import os

API_URL = 'https://api.github.com{}'
ACCEPT = 'application/vnd.github.v3+json'

class BaseObject(object):
    def __init__(self, **kwargs):
        for k, v in kwargs.items():
            setattr(self, k, v)

    def to_dict(self):
        return json.loads(self.to_json())

    def to_json(self):
        return json.dumps(self, default=lambda o: o.__dict__, sort_keys=True)

    def __str__(self):
        return self.to_json()

class Content(BaseObject):
    pass

class Author():
    def __init__(self, name, email):
        self.name = name
        self.email = email

class Response(BaseObject):
    def __init__(self):
        self.contents = []
    pass

class Github():
    def __init__(self, user, password):
        self.user = user
        self.password = password

    def set_author(self, name, email):
        self.author = Author(name, email)

    def create_from_file(self, owner, repository, filepath, path=None):
        '''
        创建文件
        https://developer.github.com/v3/repos/contents/#create-a-file
        '''
        if not path:
            path = os.path.basename(filepath)

        content = ""
        with open(filepath, 'rb') as f:
            byte_data = f.read()
            content = base64.b64encode(byte_data).decode()

        url = '/repos/{}/{}/contents/{}'.format(owner, repository, path)
        self._put(url, **{
              "message": "Create file {}".format(path),
              "author": {
                    "name": self.author.name,
                    "email": self.author.email
                  },
                "content": content
                }
            )

        data = self.response.json()
        #  print(json.dumps(data, indent=4))
        f = Content(**data['content'])
        res = Response()
        res.contents.append(f)
        return res

    def _put(self, url, **kw):
        res = requests.put(
            API_URL.format(url),
            json=kw,
            headers={"Accept": ACCEPT},
            auth=HTTPBasicAuth(self.user, self.password)
        )
        self.response = res

if __name__ == "__main__":
    g = Github('', '')
    g.create_from_file('image', '/Users/wxnacy/Downloads/mac-font2.png',
            'common/{}'.format(time.time()))




#!/usr/bin/env python
# -*- coding:utf-8 -*-
# Author: wxnacy(wxnacy@gmail.com)
# Description:

import click
from goss import Github
import configparser
import os
import pyperclip

github = None
owner = None
repo = None

def generate_github():
    config_path = '{}/.config/gos/config'.format(os.getenv("HOME"))
    credential_path = '{}/.config/gos/credentials'.format(os.getenv("HOME"))

    credential = configparser.ConfigParser()
    credential.read(credential_path)
    default_cred = credential['default']

    global github
    if not github:
        github = Github(default_cred['user'], default_cred['password'])

    config = configparser.ConfigParser()
    config.read(config_path)
    author = config['user']
    github.set_author(author['name'], author['email'])

    global owner
    global repo
    owner = config['repository']['owner']
    repo = config['repository']['repo']

def create(filepath, path=None):
    '''
    创建文件
    '''
    #  g = Github()
    click.echo('Begin upload\t: {}'.format(filepath))
    click.echo('Create to\t: https://github.com/{}/{}'.format(owner, repo))
    res = github.create_from_file(owner, repo, filepath, path)
    res.contents
    cont = res.contents[0]

    click.echo('Success!')
    click.echo('The download url is\n\n\t{}\n\nYou can use it by <ctrl-v>'.format(cont.download_url))
    pyperclip.copy(cont.download_url)

@click.command()
@click.option('-u', '--user', help='Github user')
#  @click.option('--owner', help='Github repository owner')
#  @click.option('--repo', help='Github repository name')
@click.option('--path', help='Github repository file path')
@click.argument('cmd')
@click.argument('filepath', type=click.Path(exists=True))
def run(cmd, filepath, user, path):
    '''
    Github Object Storage
    '''
    generate_github()
    if cmd == 'create':
        create(filepath, path)
    pass

if __name__ == "__main__":
    run()



#!/usr/bin/env python
# -*- coding:utf-8 -*-
# Author: wxnacy(wxnacy@gmail.com)
# Description:

import click
from goss import Github
import configparser
import os
import pyperclip

github = None
owner = None
repo = None

def generate_github():
    config_path = '{}/.config/gos/config'.format(os.getenv("HOME"))
    credential_path = '{}/.config/gos/credentials'.format(os.getenv("HOME"))

    credential = configparser.ConfigParser()
    credential.read(credential_path)
    default_cred = credential['default']

    global github
    if not github:
        github = Github(default_cred['user'], default_cred['password'])

    config = configparser.ConfigParser()
    config.read(config_path)
    author = config['user']
    github.set_author(author['name'], author['email'])

    global owner
    global repo
    owner = config['repository']['owner']
    repo = config['repository']['repo']

def create(filepath, path=None):
    '''
    创建文件
    '''
    if not path:
        path = os.path.basename(filepath)
    click.echo('{}\t\t: {}'.format(click.style('Upload', fg='yellow'), filepath))
    click.echo('{}\t\t: https://github.com/{}/{}/{}'.format(
        click.style("To", fg='yellow'),
        owner, repo, path))
    download_url = 'https://raw.githubusercontent.com/{}/{}/master/{}'.format(
        owner, repo, path
    )
    pyperclip.copy(download_url)
    click.echo('{}\t: {}'.format(
        click.style('Download url', fg='yellow'),
        click.style(download_url, fg='blue'),
    ))
    click.echo('Now you can use it in content with {}. Wait upload success it will be avaible'.format(
        click.style('<Ctrl-v>', fg='blue')
    ))
    res = github.create_from_file(owner, repo, filepath, path)
    res.contents
    cont = res.contents[0]

    click.secho('Success!', fg='cyan')

@click.command()
@click.option('-u', '--user', help='Github user')
#  @click.option('--owner', help='Github repository owner')
#  @click.option('--repo', help='Github repository name')
@click.option('--path', help='Github repository file path')
@click.argument('filepath', type=click.Path(exists=True))
def run(filepath, user, path):
    '''
    Github Object Storage
    '''
    generate_github()
    create(filepath, path)
    pass

if __name__ == "__main__":
    run()
